@@ -694,8 +694,9 @@ void on_input_clicked (GtkButton *button, guidata *gui)
       case 9:  set_ports(2, notebook, gui); break;
       case 10: set_ports(2, notebook, gui); break;
       case 11: set_ports(2, notebook, gui); break;
-      case 12: set_builtin(notebook, gui); break;
+      case 12: set_ports(2, notebook, gui); break;
       case 13: set_builtin(notebook, gui); break;
+      case 14: set_builtin(notebook, gui); break;
       default : break;
     }
 
@@ -715,7 +716,7 @@ void on_input_clicked (GtkButton *button, guidata *gui)
   {
     if (GetJoy(a,gui)>0)
     {
-      gchar *id =g_strdup_printf(" - Unique ID: %016llx\n", gui->joy[a].id); 
+      gchar *id =g_strdup_printf(" - Unique ID: %016llx\n", gui->joy[a].id);
       print_log("Joystick detected: ", FE, gui);
       print_log(gui->joy[a].name, FE, gui);
       print_log(id, FE, gui);
@@ -753,31 +754,45 @@ void on_input_clicked (GtkButton *button, guidata *gui)
     }
     else
     {
-      gui->joy[i].sdl_id = SDL_JoystickInstanceID(gui->joy[i].sdljoy);
-      gui->joy[i].name = g_strdup(SDL_JoystickName(gui->joy[i].sdljoy));
+       gui->joy[i].sdl_id = SDL_JoystickInstanceID(gui->joy[i].sdljoy);
+       gui->joy[i].name = g_strdup(SDL_JoystickName(gui->joy[i].sdljoy));
 
-      SDL_JoystickGUID guid = SDL_JoystickGetGUID(gui->joy[i].sdljoy);
-      char pszGUID[32];
-      SDL_JoystickGetGUIDString(guid, (char *)pszGUID, 33);
+       SDL_JoystickGUID guid = SDL_JoystickGetGUID(gui->joy[i].sdljoy);
+       char pszGUID[32];
+       SDL_JoystickGetGUIDString(guid, (char *)pszGUID, 33);
 
-      /*printf("GUID: %s\n", pszGUID);*/
+       /*printf("GUID: %s\n", pszGUID);*/
 
-      /*if ((guid.data[0]=='x') &&
+       /*if ((guid.data[0]=='x') &&
           (guid.data[1]=='i') &&
           (guid.data[2]=='n') &&
           (guid.data[3]=='p') &&
           (guid.data[4]=='u') &&
           (guid.data[5]=='t'))*/
-     if (g_strcmp0(pszGUID, "00000000000000000000000000000000")==0)
-     {
-      gui->joy[i].id = (0x00000000 << 24) | (0x00000001 << 16);
-      gui->joy[i].xinput = TRUE;
-     }
-     else
-     {
-      GetJoy(i, gui);
-     }
-     CheckDuplicates(i, gui);
+       if (g_strcmp0(pszGUID, "00000000000000000000000000000000")==0)
+       {
+          int type, subtype;
+
+          type =  SDL_JoystickDevType(gui->joy[i].sdljoy);      // Those functions do not exist in SDL
+          subtype = SDL_JoystickDevSubType(gui->joy[i].sdljoy); // I patched it to expose XINPUT_CAPABILITIES
+
+          if ((type > -1) &&
+              (type < 2) &&
+              (subtype > -1 ) &&
+              (subtype < 20))
+          {
+            gui->joy[i].id = ((type << 24) | (subtype << 16));
+          }
+          else gui->joy[i].id = (0x00000000 << 24) | (0x00000001 << 16);
+
+          gui->joy[i].xinput = TRUE;
+          CheckDuplicatesXInput(i, gui);
+       }
+       else
+       {
+          GetJoy(i, gui);
+       }
+       CheckDuplicates(i, gui);
     }
   }
 
